aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTreehugger Robot <android-test-infra-autosubmit@system.gserviceaccount.com>2024-03-20 22:25:15 +0000
committerGerrit Code Review <noreply-gerritcodereview@google.com>2024-03-20 22:25:15 +0000
commitbf2c7afa622f48b3fe2c5430e87bd26bd7b4219b (patch)
tree76d6a58fa64fe7ec3c111a672ec05c0fb5329330
parentddaf25104a4727ca420dec665f9c102c390a9637 (diff)
parente509f664eefc416652feb9eca57903fbe9f4898d (diff)
downloadtelephony-bf2c7afa622f48b3fe2c5430e87bd26bd7b4219b.tar.gz
Merge "Rename default value of RoamingType." into main
-rw-r--r--proto/src/telephony.proto8
1 files changed, 4 insertions, 4 deletions
diff --git a/proto/src/telephony.proto b/proto/src/telephony.proto
index b87728b53a..92f62cc011 100644
--- a/proto/src/telephony.proto
+++ b/proto/src/telephony.proto
@@ -259,8 +259,8 @@ message TelephonyServiceState {
// Roaming type
enum RoamingType {
- // Unknown. The default value. Different from ROAMING_TYPE_UNKNOWN.
- UNKNOWN = -1;
+ // Undefined. The default value. Different from ROAMING_TYPE_UNKNOWN.
+ ROAMING_TYPE_UNDEFINED = -1;
// In home network
ROAMING_TYPE_NOT_ROAMING = 0;
@@ -346,10 +346,10 @@ message TelephonyServiceState {
optional TelephonyOperator data_operator = 2;
// Current voice network roaming type
- optional RoamingType voice_roaming_type = 3 [default = UNKNOWN];
+ optional RoamingType voice_roaming_type = 3 [default = ROAMING_TYPE_UNDEFINED];
// Current data network roaming type
- optional RoamingType data_roaming_type = 4 [default = UNKNOWN];
+ optional RoamingType data_roaming_type = 4 [default = ROAMING_TYPE_UNDEFINED];
// Current voice radio technology
optional RadioAccessTechnology voice_rat = 5 [default = UNKNOWN];